@@ -16,16 +16,17 @@
 
 from google.cloud import _http
 
+from google.cloud.storage import __version__
+
+
+_CLIENT_INFO = _http.CLIENT_INFO_TEMPLATE.format(__version__)
+
 
 class Connection(_http.JSONConnection):
     """A connection to Google Cloud Storage via the JSON REST API.
 
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials`
-    :param credentials: (Optional) The OAuth2 Credentials to use for this
-                        connection.
-
-    :type http: :class:`httplib2.Http` or class that defines ``request()``.
-    :param http: (Optional) HTTP object to make requests.
+    :type client: :class:`~google.cloud.storage.client.Client`
+    :param client: The client that owns the current connection.
     """
 
     API_BASE_URL = _http.API_BASE_URL
@@ -37,7 +38,6 @@ class Connection(_http.JSONConnection):
     API_URL_TEMPLATE = '{api_base_url}/storage/{api_version}{path}'
     """A template for the URL of a particular API call."""
 
-    SCOPE = ('https://www.googleapis.com/auth/devstorage.full_control',
-             'https://www.googleapis.com/auth/devstorage.read_only',
-             'https://www.googleapis.com/auth/devstorage.read_write')
-    """The scopes required for authenticating as a Cloud Storage consumer."""
+    _EXTRA_HEADERS = {
+        _http.CLIENT_INFO_HEADER: _CLIENT_INFO,
+    }
